==> staffology-0.1.4-py3-none-any.whl: staffology/models/payroll_value_type.py <==
from enum import Enum


class PayrollValueType(str, Enum):
    BASICPAY = "BasicPay"
    GROSS = "Gross"
    GROSSFORTAX = "GrossForTax"
    GROSSFORNI = "GrossForNi"
    EMPLOYERNI = "EmployerNi"
    EMPLOYEENI = "EmployeeNi"
    EMPLOYERNIOFFPAYROLL = "EmployerNiOffPayroll"
    REALTIMECLASS1ANI = "RealTimeClass1ANi"
    TAX = "Tax"
    NETPAY = "NetPay"
    ADJUSTMENTS = "Adjustments"
    TAKEHOMEPAY = "TakeHomePay"
    NONTAXORNICPMT = "NonTaxOrNICPmt"
    ITEMSSUBJECTTOCLASS1NIC = "ItemsSubjectToClass1NIC"
    DEDNSFROMNETPAY = "DednsFromNetPay"
    TCP_TCLS = "Tcp_Tcls"
    TCP_PP = "Tcp_Pp"
    TCP_OP = "Tcp_Op"
    FLEXIDD_DEATH = "FlexiDd_Death"
    FLEXIDD_DEATH_NONTAX = "FlexiDd_Death_NonTax"
    FLEXIDD_PENSION = "FlexiDd_Pension"
    FLEXIDD_PENSION_NONTAX = "FlexiDd_Pension_NonTax"
    SMP = "Smp"
    SPP = "Spp"
    SAP = "Sap"
    SHPP = "Shpp"
    SPBP = "Spbp"
    STUDENTLOANRECOVERED = "StudentLoanRecovered"
    POSTGRADLOANRECOVERED = "PostgradLoanRecovered"
    PENSIONABLEPAY = "PensionablePay"
    NONTIERABLEPAY = "NonTierablePay"
    EMPLOYEEPENSIONCONTRIBUTION = "EmployeePensionContribution"
    EMPLOYERPENSIONCONTRIBUTION = "EmployerPensionContribution"
    EMPEEPENCONTRIBNSNOTPAID = "EmpeePenContribnsNotPaid"
    EMPEEPENCONTRIBNSPAID = "EmpeePenContribnsPaid"
    ATTACHMENTORDERDEDUCTIONS = "AttachmentOrderDeductions"
    CISDEDUCTION = "CisDeduction"
    CISVAT = "CisVat"
    CISUMBRELLAFEE = "CisUmbrellaFee"
    CISUMBRELLAFEEPOSTTAX = "CisUmbrellaFeePostTax"
    PBIK = "Pbik"
    MAPSMILES = "MapsMiles"
    UMBRELLAFEE = "UmbrellaFee"
    APPLEVYDEDUCTION = "AppLevyDeduction"
    PAYMENTAFTERLEAVING = "PaymentAfterLeaving"
    TAXONPAYMENTAFTERLEAVING = "TaxOnPaymentAfterLeaving"
    SSP = "Ssp"
    ATTACHMENTORDERADMINFEE = "AttachmentOrderAdminFee"
    EMPLOYEEPENSIONNETPAY = "EmployeePensionNetPay"
    EMPLOYEEPENSIONRAS = "EmployeePensionRas"
    EMPLOYEEPENSIONSALSAC = "EmployeePensionSalSac"
    EMPLOYEEPENSIONCONTRIBUTIONAVC = "EmployeePensionContributionAvc"
    DEDUCTIONS = "Deductions"
    ADDITIONS = "Additions"
    PENSIONABLEEARNINGS = "PensionableEarnings"

    def __str__(self) -> str:
        return str(self.value)

==> staffology-0.1.7-py3-none-any.whl: staffology/models/payroll_value_type.py <==
from enum import Enum


class PayrollValueType(str, Enum):
    BASICPAY = "BasicPay"
    GROSS = "Gross"
    GROSSFORTAX = "GrossForTax"
    GROSSFORNI = "GrossForNi"
    EMPLOYERNI = "EmployerNi"
    EMPLOYEENI = "EmployeeNi"
    EMPLOYERNIOFFPAYROLL = "EmployerNiOffPayroll"
    REALTIMECLASS1ANI = "RealTimeClass1ANi"
    TAX = "Tax"
    NETPAY = "NetPay"
    ADJUSTMENTS = "Adjustments"
    TAKEHOMEPAY = "TakeHomePay"
    NONTAXORNICPMT = "NonTaxOrNICPmt"
    ITEMSSUBJECTTOCLASS1NIC = "ItemsSubjectToClass1NIC"
    DEDNSFROMNETPAY = "DednsFromNetPay"
    TCP_TCLS = "Tcp_Tcls"
    TCP_PP = "Tcp_Pp"
    TCP_OP = "Tcp_Op"
    FLEXIDD_DEATH = "FlexiDd_Death"
    FLEXIDD_DEATH_NONTAX = "FlexiDd_Death_NonTax"
    FLEXIDD_PENSION = "FlexiDd_Pension"
    FLEXIDD_PENSION_NONTAX = "FlexiDd_Pension_NonTax"
    SMP = "Smp"
    SPP = "Spp"
    SAP = "Sap"
    SHPP = "Shpp"
    SPBP = "Spbp"
    STUDENTLOANRECOVERED = "StudentLoanRecovered"
    POSTGRADLOANRECOVERED = "PostgradLoanRecovered"
    PENSIONABLEPAY = "PensionablePay"
    NONTIERABLEPAY = "NonTierablePay"
    EMPLOYEEPENSIONCONTRIBUTION = "EmployeePensionContribution"
    EMPLOYERPENSIONCONTRIBUTION = "EmployerPensionContribution"
    EMPEEPENCONTRIBNSNOTPAID = "EmpeePenContribnsNotPaid"
    EMPEEPENCONTRIBNSPAID = "EmpeePenContribnsPaid"
    ATTACHMENTORDERDEDUCTIONS = "AttachmentOrderDeductions"
    CISDEDUCTION = "CisDeduction"
    CISVAT = "CisVat"
    CISUMBRELLAFEE = "CisUmbrellaFee"
    CISUMBRELLAFEEPOSTTAX = "CisUmbrellaFeePostTax"
    PBIK = "Pbik"
    MAPSMILES = "MapsMiles"
    UMBRELLAFEE = "UmbrellaFee"
    APPLEVYDEDUCTION = "AppLevyDeduction"
    PAYMENTAFTERLEAVING = "PaymentAfterLeaving"
    TAXONPAYMENTAFTERLEAVING = "TaxOnPaymentAfterLeaving"
    SSP = "Ssp"
    ATTACHMENTORDERADMINFEE = "AttachmentOrderAdminFee"
    EMPLOYEEPENSIONNETPAY = "EmployeePensionNetPay"
    EMPLOYEEPENSIONRAS = "EmployeePensionRas"
    EMPLOYEEPENSIONSALSAC = "EmployeePensionSalSac"
    EMPLOYEEPENSIONCONTRIBUTIONAVC = "EmployeePensionContributionAvc"
    DEDUCTIONS = "Deductions"
    ADDITIONS = "Additions"
    PENSIONABLEEARNINGS = "PensionableEarnings"
    TOTALGROSS = "TotalGross"
    FLEXIDD_SERIOUSILLHEALTH = "FlexiDd_SeriousIllHealth"
    FLEXIDD_SERIOUSILLHEALTH_NONTAX = "FlexiDd_SeriousIllHealth_NonTax"
    FOREIGNTAXCREDIT = "ForeignTaxCredit"
    FOREIGNTAXRECLAIMED = "ForeignTaxReclaimed"
    AVERAGEHOLIDAYPAY = "AverageHolidayPay"
    P45GROSS = "P45Gross"
    P45TAX = "P45Tax"

    def __str__(self) -> str:
        return str(self.value)

    @classmethod
    def _missing_(cls, value):
        #  Staffology API sometimes sends the index value inside an enum instead of the value of the enum itself
        value_from_index = list(dict(cls.__members__).values())[int(value)]
        return cls(value_from_index)
